@@ -1,27 +1,29 @@
 package App::pherkin;
-$App::pherkin::VERSION = '0.45';
+$App::pherkin::VERSION = '0.53';
 use strict;
 use warnings;
 
 use lib;
 use Getopt::Long;
-use Module::Runtime qw(use_module);
+use Module::Runtime qw(use_module module_notional_filename);
 use List::Util qw(max);
 use Pod::Usage;
 use FindBin qw($RealBin $Script);
 use YAML::Syck;
 use Data::Dumper;
+use File::Spec;
 use Path::Class qw/file dir/;
 
 use Test::BDD::Cucumber::I18n
-  qw(languages langdef readable_keywords keyword_to_subname);
+    qw(languages langdef readable_keywords keyword_to_subname);
 use Test::BDD::Cucumber::Loader;
 
-use Moose;
-has 'step_paths' => ( is => 'rw', isa => 'ArrayRef', default => sub { [] } );
-has 'extensions' => ( is => 'rw', isa => 'ArrayRef', default => sub { [] } );
-has 'tags'       => ( is => 'rw', isa => 'ArrayRef', required => 0 );
-has 'tag_scheme' => ( is => 'rw', isa => 'ArrayRef', required => 0 );
+use Moo;
+use Types::Standard qw( ArrayRef );
+has 'step_paths' => ( is => 'rw', isa => ArrayRef, default => sub { [] } );
+has 'extensions' => ( is => 'rw', isa => ArrayRef, default => sub { [] } );
+has 'tags'       => ( is => 'rw', isa => ArrayRef, required => 0 );
+has 'tag_scheme' => ( is => 'rw', isa => ArrayRef, required => 0 );
 
 has 'harness' => ( is => 'rw' );
 
@@ -31,7 +33,7 @@ App::pherkin - Run Cucumber tests from the command line
 
 =head1 VERSION
 
-version 0.45
+version 0.53
 
 =head1 SYNOPSIS
 
@@ -61,24 +63,31 @@ Returns a L<Test::BDD::Cucumber::Model::Result> object for all steps run.
 
 =cut
 
-sub run {
+sub _pre_run {
     my ( $self, @arguments ) = @_;
 
- # localized features will have utf8 in them and options may output utf8 as well
+    # localized features will have utf8 in them and options may output utf8 as
+    # well
     binmode STDOUT, ':utf8';
 
     my ($features_path) = $self->_process_arguments(@arguments);
     $features_path ||= './features/';
 
     my ( $executor, @features ) =
-      Test::BDD::Cucumber::Loader->load( $features_path, $self->tag_scheme );
+      Test::BDD::Cucumber::Loader->load( $features_path );
     die "No feature files found in $features_path" unless @features;
 
     $executor->add_extensions($_) for @{ $self->extensions };
 
     Test::BDD::Cucumber::Loader->load_steps( $executor, $_ )
-      for @{ $self->step_paths };
+        for @{ $self->step_paths };
 
+    return ( $executor, @features );
+}
+
+sub run {
+    my ( $self,     @arguments ) = @_;
+    my ( $executor, @features )  = $self->_pre_run(@arguments);
     return $self->_run_tests( $executor, @features );
 }
 
@@ -94,7 +103,9 @@ sub _run_tests {
             { tags => $self->tag_scheme } );
     }
 
+    $_->pre_execute() for @{ $self->extensions };
     $executor->execute( $_, $harness, $tag_spec ) for @features;
+    $_->post_execute() for reverse @{ $self->extensions };
 
     $harness->shutdown();
     return $harness->result;
@@ -108,7 +119,7 @@ sub _initialize_harness {
     }
 
     eval { use_module($harness_module) }
-      || die "Unable to load harness [$harness_module]: $@";
+        || die "Unable to load harness [$harness_module]: $@";
 
     $self->harness( $harness_module->new() );
 }
@@ -125,18 +136,16 @@ sub _find_config_file {
         map { ( "$_.yaml", "$_.yml" ) } (
 
             # Relative locations
-            (
-                map { file($_) }
-                  qw!.pherkin config/pherkin ./.config/pherkin t/.pherkin!
+            (   map { file($_) }
+                    qw!.pherkin config/pherkin ./.config/pherkin t/.pherkin!
             ),
 
             # Home locations
-            (
-                map { dir($_)->file('.pherkin') }
-                grep { $_ } map { $ENV{$_} } qw/HOME USERPROFILE/
+            (   map { dir($_)->file('.pherkin') }
+                grep {$_} map { $ENV{$_} } qw/HOME USERPROFILE/
             )
         )
-      )
+        )
     {
         return $_ if -f $_;
         print "No config file found in $_\n" if $debug;
@@ -147,8 +156,8 @@ sub _find_config_file {
 sub _load_config {
     my ( $self, $profile_name, $proposed_config_filename, $debug ) = @_;
 
-    my $config_filename =
-      $self->_find_config_file( $proposed_config_filename, $debug );
+    my $config_filename
+        = $self->_find_config_file( $proposed_config_filename, $debug );
     my $config_data_whole;
 
     # Check we can actually load some data from that file if required
@@ -159,26 +168,26 @@ sub _load_config {
         if ($profile_name) {
             print "No configuration files found\n" if $debug;
             die
-"Profile name [$profile_name] specified, but no configuration file found (use --debug-profiles to debug)";
+                "Profile name [$profile_name] specified, but no configuration file found (use --debug-profiles to debug)";
         } else {
             print "No configuration files found, and no profile specified\n"
-              if $debug;
+                if $debug;
             return;
         }
     }
 
-    $profile_name //= 'default';
+    $profile_name = 'default' unless defined $profile_name;
 
     # Check the config file has the right type of data at the profile name
     unless ( ref $config_data_whole eq 'HASH' ) {
         die
-"Config file [$config_filename] doesn't return a hashref on parse, instead a ["
-          . ref($config_data_whole) . ']';
+            "Config file [$config_filename] doesn't return a hashref on parse, instead a ["
+            . ref($config_data_whole) . ']';
     }
     my $config_data     = $config_data_whole->{$profile_name};
     my $profile_problem = sub {
         return "Config file [$config_filename] profile [$profile_name]: "
-          . shift();
+            . shift();
     };
     unless ($config_data) {
         die $profile_problem->("Profile not found");
@@ -194,10 +203,18 @@ sub _load_config {
         my $value = $config_data->{$key};
 
         if ( my $reftype = ref $value ) {
-            die $profile_problem->(
-"Option $key is a [$reftype] but can only be a single value or ARRAY"
-            ) unless $reftype eq 'ARRAY';
-            push( @arguments, $key, $_ ) for @$value;
+            if ( $key ne 'extensions' ) {
+                die $profile_problem->(
+                    "Option $key is a [$reftype] but can only be a single value or ARRAY"
+                ) unless $reftype eq 'ARRAY';
+                push( @arguments, $key, $_ ) for @$value;
+            } else {
+                die $profile_problem->(
+                    "Option $key is a [$reftype] but can only be a HASH as '$key' is"
+                        . " a special case - see the documentation for details"
+                ) unless $reftype eq 'HASH' && $key eq 'extensions';
+                push( @arguments, $key, $value );
+            }
         } else {
             push( @arguments, $key, $value );
         }
@@ -233,13 +250,13 @@ sub _process_arguments {
         steps      => [ 's|steps=s@', [] ],
         tags       => [ 't|tags=s@', [] ],
         i18n       => ['i18n=s'],
-        extensions => [ 'e|extensions=s@', [] ],
+        extensions => [ 'e|extension=s@', [] ],
     );
 
     GetOptions(
         map {
             my $x;
-            $_->[1] //= \$x;
+            $_->[1] = \$x unless defined $_->[1];
             ( $_->[0] => $_->[1] );
         } values %options
     );
@@ -255,16 +272,28 @@ sub _process_arguments {
         -input   => "$RealBin/$Script",
     ) if $deref->('help');
 
+    my @parsed_extensions;
+    for my $e ( @{ $deref->('extensions') } ) {
+        my $e_args = "()";
+        $e_args = $1 if $e =~ s/\((.+)\)$//;
+        my @e_args = eval $e_args;
+        die "Bad arguments in [$e]: $@" if $@;
+
+        push( @parsed_extensions, [ $e, \@e_args ] );
+    }
+    $options{extensions}->[1] = \@parsed_extensions;
+
     # Load the configuration file
     my @configuration_options = $self->_load_config( map { $deref->($_) }
-          qw/profile config debug_profiles/ );
+            qw/profile config debug_profiles/ );
 
     # Merge those configuration items
     # First we need a list of matching keys
     my %keys = map {
-        my ( $key_basis, $ref ) = @$_;
-        map { $_ => $ref } map { s/=.+//; $_ } split( /\|/, $key_basis );
-    } values %options;
+        my ( $key_basis, $ref ) = @{ $options{$_} };
+        map { $_ => $ref }
+            map { s/=.+//; $_ } ( split( /\|/, $key_basis ), $_ );
+    } keys %options;
 
     # Now let's go through each option. For arrays, we want the configuration
     # options to appear in order at the front. So if configuration had 1, 2,
@@ -276,24 +305,37 @@ sub _process_arguments {
         my ($value) = shift(@configuration_options);
         my $target = $keys{$key} || die "Unknown configuration option [$key]";
 
-        if ( ref $target ne 'ARRAY' ) {
+        if ( $key eq 'extensions' || $key eq 'extension' ) {
+            die "Value of $key in config file expected to be HASH but isn't"
+                if ref $value ne 'HASH';
+
+            # if the configuration of the extension is 'undef', then
+            # none was defined. Replace it with an empty hashref, which
+            # is what Moo's 'new()' method wants later on
+            my @e = map { [ $_, [ $value->{$_} || {} ] ] } keys %$value;
+            $value = \@e;
+            my $array = $additions{ 0 + $target } ||= [];
+            push( @$array, @$value );
+            print "Adding extensions near the front of $key"
+                if $deref->('debug_profiles');
+        } elsif ( ref $target ne 'ARRAY' ) {
 
             # Only use it if we don't have something already
             if ( defined $$target ) {
                 print
-"Ignoring $key from config file because set on cmd line as $$target\n"
-                  if $deref->('debug_profiles');
+                    "Ignoring $key from config file because set on cmd line as $$target\n"
+                    if $deref->('debug_profiles');
             } else {
                 $$target = $value;
                 print "Set $key to $target from config file\n"
-                  if $deref->('debug_profiles');
+                    if $deref->('debug_profiles');
             }
 
         } else {
             my $array = $additions{ 0 + $target } ||= [];
             push( @$array, $value );
             print "Adding $value near the front of $key\n"
-              if $deref->('debug_profiles');
+                if $deref->('debug_profiles');
         }
     }
     for my $target ( values %options ) {
@@ -310,7 +352,7 @@ sub _process_arguments {
             if ( ref $value ) {
                 print join ', ', @$value;
             } else {
-                print $value // '[undefined]';
+                print( ( defined $value ) ? $value : '[undefined]' );
             }
             print "\n";
         }
@@ -324,19 +366,23 @@ sub _process_arguments {
 
     unshift @{ $deref->('includes') }, 'lib' if $deref->('lib');
     unshift @{ $deref->('includes') }, 'blib/lib', 'blib/arch'
-      if $deref->('blib');
+        if $deref->('blib');
 
     # We may need some of the imported paths...
     lib->import( @{ $deref->('includes') } );
 
     # Load any extensions
     for my $e ( @{ $deref->('extensions') } ) {
-        my $e_args = "()";
-        $e_args = $1 if $e =~ s/\((.+)\)$//;
-        my @e_args = eval $e_args;
-        die "Bad arguments in [$e]: $@" if $@;
-        use_module $e;
-        push( @{ $self->extensions }, $e->new(@e_args) );
+        my ( $c, $a ) = @$e;
+        use_module $c;
+
+        my $instance = $c->new(@$a);
+        push( @{ $self->extensions }, $instance );
+
+        my $dir = file( $INC{ module_notional_filename($c) } )->dir;
+        my @step_dirs = map { File::Spec->rel2abs( $_, $dir ) }
+            @{ $instance->step_directories };
+        unshift( @{ $deref->('steps') }, @step_dirs );
     }
 
     # Munge the output harness
@@ -391,14 +437,14 @@ sub _print_languages {
 
     my @languages = languages();
 
-    my $max_code_length = max map { length } @languages;
-    my $max_name_length =
-      max map { length( langdef($_)->{name} ) } @languages;
-    my $max_native_length =
-      max map { length( langdef($_)->{native} ) } @languages;
+    my $max_code_length = max map {length} @languages;
+    my $max_name_length
+        = max map { length( langdef($_)->{name} ) } @languages;
+    my $max_native_length
+        = max map { length( langdef($_)->{native} ) } @languages;
 
-    my $format =
-"| %-${max_code_length}s | %-${max_name_length}s | %-${max_native_length}s |\n";
+    my $format
+        = "| %-${max_code_length}s | %-${max_name_length}s | %-${max_native_length}s |\n";
 
     for my $language ( sort @languages ) {
         my $langdef = langdef($language);
@@ -413,15 +459,15 @@ sub _print_langdef {
     my $langdef = langdef($language);
 
     my @keywords = qw(feature background scenario scenario_outline examples
-      given when then and but);
-    my $max_length =
-      max map { length readable_keywords( $langdef->{$_} ) } @keywords;
+        given when then and but);
+    my $max_length
+        = max map { length readable_keywords( $langdef->{$_} ) } @keywords;
 
     my $format = "| %-16s | %-${max_length}s |\n";
     for my $keyword (
         qw(feature background scenario scenario_outline
         examples given when then and but )
-      )
+        )
     {
         printf $format, $keyword, readable_keywords( $langdef->{$keyword} );
     }
@@ -429,7 +475,7 @@ sub _print_langdef {
     my $codeformat = "| %-16s | %-${max_length}s |\n";
     for my $keyword (qw(given when then )) {
         printf $codeformat, $keyword . ' (code)',
-          readable_keywords( $langdef->{$keyword}, \&keyword_to_subname );
+            readable_keywords( $langdef->{$keyword}, \&keyword_to_subname );
     }
 
     exit;
@@ -441,7 +487,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-Copyright 2011-2014, Peter Sergeant; Licensed under the same terms as Perl
+Copyright 2011-2016, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
 
