@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Executor;
-$Test::BDD::Cucumber::Executor::VERSION = '0.45';
+$Test::BDD::Cucumber::Executor::VERSION = '0.53';
 =head1 NAME
 
 Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.45
+version 0.53
 
 =head1 DESCRIPTION
 
@@ -15,7 +15,9 @@ Definitions, and reporting on progress through the passed-in harness.
 
 =cut
 
-use Moose;
+use Moo;
+use MooX::HandlesVia;
+use Types::Standard qw( Bool ArrayRef HashRef );
 use Clone qw(clone);
 use List::Util qw/first/;
 use List::MoreUtils qw/pairwise/;
@@ -66,7 +68,7 @@ use Test::BDD::Cucumber::Util;
 use Test::BDD::Cucumber::Model::Result;
 use Test::BDD::Cucumber::Errors qw/parse_error_from_line/;
 
-has '_bail_out' => ( is => 'rw', isa => 'Bool', default => 0 );
+has '_bail_out' => ( is => 'rw', isa => Bool, default => 0 );
 
 =head1 METHODS
 
@@ -92,9 +94,9 @@ The C<pre_*> will be called in order 2, 3, 1, and C<post_*> will be called in
 
 has extensions => (
     is      => 'ro',
-    isa     => 'ArrayRef',
-    traits  => ['Array'],
+    isa     => ArrayRef,
     default => sub { [] },
+    handles_via => 'Array',
     handles => { add_extensions => 'unshift' },
 );
 
@@ -113,7 +115,7 @@ and populates C<steps> with them.
 
 =cut
 
-has 'steps' => ( is => 'rw', isa => 'HashRef', default => sub { {} } );
+has 'steps' => ( is => 'rw', isa => HashRef, default => sub { {} } );
 
 sub add_steps {
     my ( $self, @steps ) = @_;
@@ -219,10 +221,10 @@ the Harness interface.
 sub execute_scenario {
     my ( $self, $options ) = @_;
     my ( $feature, $feature_stash, $harness, $outline, $background_obj,
-        $incoming_scenario_stash, $incoming_outline_stash )
+        $incoming_scenario_stash, $incoming_outline_state )
       = @$options{
         qw/ feature feature_stash harness scenario background scenario_stash
-          outline_stash
+          outline_state
           /
       };
 
@@ -231,8 +233,8 @@ sub execute_scenario {
     my $harness_start = $is_background ? 'background'      : 'scenario';
     my $harness_stop  = $is_background ? 'background_done' : 'scenario_done';
 
-    my $outline_stash = $incoming_outline_stash || {};
-    $outline_stash->{'short_circuit'} ||= $self->_bail_out;
+    my $outline_state = $incoming_outline_state || {};
+    $outline_state->{'short_circuit'} ||= $self->_bail_out;
 
     # Multiply out Scenario Outlines as appropriate
     my @datasets = @{ $outline->data };
@@ -280,11 +282,11 @@ sub execute_scenario {
 
                 my $result =
                   $self->dispatch( $context, $before_step,
-                    $outline_stash->{'short_circuit'}, 0 );
+                    $outline_state->{'short_circuit'}, 0 );
 
                 # If it didn't pass, short-circuit the rest
                 unless ( $result->result eq 'passing' ) {
-                    $outline_stash->{'short_circuit'} = 1;
+                    $outline_state->{'short_circuit'} = 1;
                 }
             }
         }
@@ -300,7 +302,7 @@ sub execute_scenario {
                     feature_stash  => $feature_stash,
                     harness        => $harness,
                     scenario_stash => $scenario_stash,
-                    outline_stash  => $outline_stash
+                    outline_state  => $outline_state
                 }
             );
         }
@@ -310,6 +312,12 @@ sub execute_scenario {
             # Multiply out any placeholders
             my $text =
               $self->add_placeholders( $step->text, $dataset, $step->line );
+            my $data = $step->data;
+            $data = (ref $data) ?
+                $self->add_table_placeholders( $data, $dataset, $step->line )
+                : (defined $data) ?
+                $self->add_placeholders( $data, $dataset, $step->line )
+                : '';
 
             # Set up a context
             my $context = Test::BDD::Cucumber::StepContext->new(
@@ -318,9 +326,7 @@ sub execute_scenario {
 
                     # Data portion
                     columns => $step->columns || [],
-                    data => ref( $step->data )
-                    ? clone( $step->data )
-                    : $step->data || '',
+                    data => $data,
 
                     # Step-specific info
                     step => $step,
@@ -331,11 +337,11 @@ sub execute_scenario {
 
             my $result =
               $self->find_and_dispatch( $context,
-                $outline_stash->{'short_circuit'}, 0 );
+                $outline_state->{'short_circuit'}, 0 );
 
             # If it didn't pass, short-circuit the rest
             unless ( $result->result eq 'passing' ) {
-                $outline_stash->{'short_circuit'}++;
+                $outline_state->{'short_circuit'}++;
             }
 
         }
@@ -351,7 +357,7 @@ sub execute_scenario {
                 my $result = $self->dispatch( $context, $after_step, 0, 0 );
             }
             $_->post_scenario( $outline, $feature_stash, $scenario_stash,
-                $outline_stash->{'short_circuit'} )
+                $outline_state->{'short_circuit'} )
               for reverse @{ $self->extensions };
 
         }
@@ -379,6 +385,28 @@ sub add_placeholders {
     return Test::BDD::Cucumber::Util::bs_unquote($quoted_text);
 }
 
+
+=head2 add_table_placeholders
+
+Accepts a hash with parsed table data and a hashref, and replaces
+C< <placeholders> > with the values in the hashref, returning a copy of the
+parsed table hashref.
+
+=cut
+
+sub add_table_placeholders {
+    my ($self, $tbl, $dataset, $line) = @_;
+    my @rv = map {
+        my $row = $_;
+        my %inner_rv =
+            map { $_ => $self->add_placeholders($row->{$_}, $dataset, $line)
+        } keys %$row;
+        \%inner_rv;
+    } @$tbl;
+    return \@rv;
+}
+
+
 =head2 find_and_dispatch
 
 Accepts a L<Test::BDD::Cucumber::StepContext> object, and searches through
@@ -470,6 +498,7 @@ sub dispatch {
 
     # New scope for the localization
     my $result;
+    my $stash_keys = join ';', sort keys %{$context->stash};
     {
         # Localize test builder
         local $Test::Builder::Test->{'_wraps'} = $tb_return->{'builder'};
@@ -525,6 +554,8 @@ sub dispatch {
             }
         );
     }
+    warn qq|Unsupported: Step modified C->stash instead of C->stash->{scenario} or C->stash->{feature}|
+        if $stash_keys ne (join ';', sort keys %{$context->stash});
 
     my @clean_matches =
       $self->_extract_match_strings( $context->text, \@match_locations );
@@ -665,7 +696,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-Copyright 2011-2014, Peter Sergeant; Licensed under the same terms as Perl
+Copyright 2011-2016, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
 
