@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Harness;
-$Test::BDD::Cucumber::Harness::VERSION = '0.45';
+$Test::BDD::Cucumber::Harness::VERSION = '0.53';
 =head1 NAME
 
 Test::BDD::Cucumber::Harness - Base class for creating harnesses
 
 =head1 VERSION
 
-version 0.45
+version 0.53
 
 =head1 DESCRIPTION
 
@@ -24,9 +24,10 @@ interacting with L<Test::BDD::Cucumber::Harness::Data>.
 
 use strict;
 use warnings;
-use Moose;
+use Moo;
+use Types::Standard qw( ArrayRef );
 
-has 'results' => ( is => 'ro', default => sub { [] }, isa => 'ArrayRef' );
+has 'results' => ( is => 'ro', default => sub { [] }, isa => ArrayRef );
 
 =head2 feature
 
@@ -46,7 +47,7 @@ sub feature_done { my ( $self, $feature ) = @_; }
 
 If you have a background section, then we execute it as a quasi-scenario step
 before each scenario. These hooks are fired before and after that, and passed
-in the L<Test::BDD::Cucmber::Model::Scenario> that represents the Background
+in the L<Test::BDD::Cucumber::Model::Scenario> that represents the Background
 section, and a a dataset hash (although why would you use that?)
 
 =cut
@@ -59,7 +60,7 @@ sub background_done { my ( $self, $scenario, $dataset ) = @_; }
 =head2 scenario_done
 
 Called at the start and end of scenario execution respectively. Both methods
-accept a L<Test::BDD::Cucmber::Model::Scenario> module and a dataset hash.
+accept a L<Test::BDD::Cucumber::Model::Scenario> module and a dataset hash.
 
 =cut
 
@@ -71,7 +72,7 @@ sub scenario_done { my ( $self, $scenario, $dataset ) = @_; }
 =head2 step_done
 
 Called at the start and end of step execution respectively. Both methods
-accept a L<Test::BDD::Cucmber::StepContext> object. C<step_done> also accepts
+accept a L<Test::BDD::Cucumber::StepContext> object. C<step_done> also accepts
 a L<Test::BDD::Cucumber::Model::Result> object and an arrayref of arrayrefs with
 locations of consolidated matches, for highlighting.
 
@@ -144,7 +145,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-Copyright 2011-2014, Peter Sergeant; Licensed under the same terms as Perl
+Copyright 2011-2016, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
 
