@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Harness::JSON;
-$Test::BDD::Cucumber::Harness::JSON::VERSION = '0.50';
+$Test::BDD::Cucumber::Harness::JSON::VERSION = '0.53';
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::JSON - Generate results to JSON file
 
 =head1 VERSION
 
-version 0.50
+version 0.53
 
 =head1 DESCRIPTION
 
@@ -17,7 +17,8 @@ L<"Publish pretty cucumber reports"|https://github.com/masterthought/cucumber-re
 
 =cut
 
-use Moose;
+use Moo;
+use Types::Standard qw( Num HashRef ArrayRef FileHandle );
 use JSON::MaybeXS;
 use Time::HiRes qw ( time );
 
@@ -31,7 +32,7 @@ A filehandle to write output to; defaults to C<STDOUT>
 
 =cut
 
-has 'fh' => ( is => 'rw', isa => 'FileHandle', default => sub { \*STDOUT } );
+has 'fh' => ( is => 'rw', isa => FileHandle, default => sub { \*STDOUT } );
 
 =head2 json_args
 
@@ -41,16 +42,16 @@ List of options to be passed to L<JSON::MaybeXS>'s C<new()> method
 
 has json_args => (
     is      => 'ro',
-    isa     => 'HashRef',
+    isa     => HashRef,
     default => sub { { utf8 => 1, pretty => 1 } }
 );
 
 #
 
-has all_features => ( is => 'ro', isa => 'ArrayRef', default => sub { [] } );
-has current_feature  => ( is => 'rw', isa => 'HashRef' );
-has current_scenario => ( is => 'rw', isa => 'HashRef' );
-has step_start_at    => ( is => 'rw', isa => 'Num' );
+has all_features => ( is => 'ro', isa => ArrayRef, default => sub { [] } );
+has current_feature  => ( is => 'rw', isa => HashRef );
+has current_scenario => ( is => 'rw', isa => HashRef );
+has step_start_at    => ( is => 'rw', isa => Num );
 
 sub feature {
     my ( $self, $feature ) = @_;
@@ -64,6 +65,11 @@ sub scenario {
     push @{ $self->current_feature->{elements} }, $self->current_scenario;
 }
 
+sub scenario_done {
+    my $self = shift;
+    $self->current_scenario( {} );
+}
+
 sub step {
     my ( $self, $context ) = @_;
     $self->step_start_at( time() );
