@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Model::TagSpec;
-$Test::BDD::Cucumber::Model::TagSpec::VERSION = '0.50';
+$Test::BDD::Cucumber::Model::TagSpec::VERSION = '0.53';
 =head1 NAME
 
 Test::BDD::Cucumber::Model::TagSpec - Encapsulates tag selectors
 
 =head1 VERSION
 
-version 0.50
+version 0.53
 
 =head1 DESCRIPTION
 
@@ -17,7 +17,8 @@ way.
 
 use strict;
 use warnings;
-use Moose;
+use Moo;
+use Types::Standard qw( ArrayRef );
 use Clone qw/clone/;
 
 =head1 OVERVIEW
@@ -38,11 +39,11 @@ don't do that. The C<not> function accepts only one argument.
 
 I<eg>:
 
-@important AND @billing: C<[and => 'important', 'billing']>
+@important AND @billing: C<<[and => 'important', 'billing']>>
 
-(@billing OR @WIP) AND @important: C<[ and => [ or => 'billing', 'wip' ], 'important' ]>
+(@billing OR @WIP) AND @important: C<<[ and => [ or => 'billing', 'wip' ], 'important' ]>>
 
-Skipping both @todo and @wip tags: C<[ and => [ not => 'todo' ], [ not => 'wip' ] ]>
+Skipping both @todo and @wip tags: C<<[ and => [ not => 'todo' ], [ not => 'wip' ] ]>>
 
 =head1 ATTRIBUTES
 
@@ -51,12 +52,12 @@ Skipping both @todo and @wip tags: C<[ and => [ not => 'todo' ], [ not => 'wip'
 An arrayref representing a structure like the above.
 
  TagSet->new({
-	tags => [ and => 'green', 'blue', [ or => 'red', 'yellow' ], [ not => 'white' ] ]
+        tags => [ and => 'green', 'blue', [ or => 'red', 'yellow' ], [ not => 'white' ] ]
  })
 
 =cut
 
-has 'tags' => ( is => 'rw', isa => 'ArrayRef', default => sub { [] } );
+has 'tags' => ( is => 'rw', isa => ArrayRef, default => sub { [] } );
 
 =head1 METHODS
 
