@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Parser;
-$Test::BDD::Cucumber::Parser::VERSION = '0.45';
+$Test::BDD::Cucumber::Parser::VERSION = '0.53';
 =head1 NAME
 
 Test::BDD::Cucumber::Parser - Parse Feature files
 
 =head1 VERSION
 
-version 0.45
+version 0.53
 
 =head1 DESCRIPTION
 
@@ -32,8 +32,6 @@ L<Test::BDD::Cucumber::Model::Feature> object on success.
 use strict;
 use warnings;
 
-use File::Slurp;
-
 use Test::BDD::Cucumber::Model::Document;
 use Test::BDD::Cucumber::Model::Feature;
 use Test::BDD::Cucumber::Model::Scenario;
@@ -46,34 +44,36 @@ use Test::BDD::Cucumber::Errors qw/parse_error_from_line/;
 # https://github.com/cucumber/cucumber/wiki/Scenario-outlines
 
 sub parse_string {
-    my ( $class, $string, $tag_scheme ) = @_;
+    my ( $class, $string ) = @_;
 
     return $class->_construct(
         Test::BDD::Cucumber::Model::Document->new(
             {
                 content => $string
             }
-        ),
-        $tag_scheme
+        )
     );
 }
 
 sub parse_file {
-    my ( $class, $string, $tag_scheme ) = @_;
-    return $class->_construct(
-        Test::BDD::Cucumber::Model::Document->new(
-            {
-                content =>
-                  scalar( read_file( $string, { binmode => ':utf8' } ) ),
-                filename => '' . $string
-            }
-        ),
-        $tag_scheme
-    );
+    my ( $class, $string ) = @_;
+    {
+        local $/;
+        open(my $in, '<', $string) or die $?;
+        binmode $in, 'utf8';
+        return $class->_construct(
+            Test::BDD::Cucumber::Model::Document->new(
+                {
+                    content => <$in>,
+                    filename => '' . $string
+                }
+            )
+        );
+    }
 }
 
 sub _construct {
-    my ( $class, $document, $tag_scheme ) = @_;
+    my ( $class, $document ) = @_;
 
     my $feature =
       Test::BDD::Cucumber::Model::Feature->new( { document => $document } );
@@ -359,10 +359,15 @@ sub _extract_table {
 
 sub _pipe_array {
     my ( $self, $string ) = @_;
-    my @atoms = split( /\|/, $string );
+    my @atoms = split( /(?<!\\)\|/, $string );
     shift(@atoms);
-    return
-      map { my $atom = $_; $atom =~ s/^\s+//; $atom =~ s/\s+$//; $atom } @atoms;
+    return map {
+        my $atom = $_;
+        $atom =~ s/^\s+//;
+        $atom =~ s/\s+$//;
+        $atom =~ s/\\(.)/$1/g;
+        $atom
+    } @atoms;
 }
 
 1;
@@ -373,6 +378,6 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-Copyright 2011-2014, Peter Sergeant; Licensed under the same terms as Perl
+Copyright 2011-2016, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
